@@ -4,12 +4,12 @@ import re
 def remove_csi(text):
     return (
         re.sub(
-            r"\\x1[bB]\[[\d;]*[a-zA-Z]{1}",
+            r"\\x1[bB]\[[\d;]*[a-zA-Z]",
             "",
             text.encode("unicode_escape").decode(),
         )
-            .encode()
-            .decode("unicode_escape")
+        .encode()
+        .decode("unicode_escape")
     )
 
 
@@ -23,9 +23,9 @@ def screate(string, size=10, insert="r", filler_symbol=" "):
         return spaces + string
 
 
-def sslice(text, chunkSize):
+def sslice(text, chunk_size):
     text = str(text)
-    return [text[i: i + chunkSize] for i in range(0, len(text), chunkSize)]
+    return [text[i : i + chunk_size] for i in range(0, len(text), chunk_size)]
 
 
 def parse_args(readed):
@@ -36,7 +36,7 @@ def parse_args(readed):
     # [\"][a-zA-ZА-Яа-яЁё\d\s[\]{}()@#_=%?\*\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d\.[\]{}()@\\\.:;,\'-/]+ (NOW)
 
     res = re.findall(
-        r"[\"][a-zA-ZА-Яа-яЁё\d\s[\]{}()@#_=%?\*\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d\.[\]{}()@\\\.:;,\'-/]+",
+        r"[\"][a-zA-ZА-Яа-яЁё\d\s[\]{}()@#_=%?*\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-Яа-яЁё\d.[\]{}()@\\:;,\'-/]+",
         readed,
         re.MULTILINE,
     )
@@ -49,4 +49,9 @@ def parse_args(readed):
     if len(res) == 1:
         return {"command": res[0], "param": [], "paramCount": 0, "split": [res[0]]}
     else:
-        return {"command": res[0], "param": res[1:], "paramCount": len(res[1:]), "split": res}
+        return {
+            "command": res[0],
+            "param": res[1:],
+            "paramCount": len(res[1:]),
+            "split": res,
+        }
